import{O as s}from"./workspaceStore.50ef2df1.js";import{d as i,J as l,a5 as u,f as a,b as n,u as o,o as f,g as d,A as c,da as b}from"./jwt-decode.esm.7f2ef0df.js";import"./userStore.73b89fbb.js";import"./url.8583a595.js";import"./colorHelpers.71d6d61d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="db14b141-fadf-44ab-9ec5-931b30d10fd8",e._sentryDebugIdIdentifier="sentry-dbid-db14b141-fadf-44ab-9ec5-931b30d10fd8")}catch{}})();const g=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new s().loginCallback()}),(t,r)=>(f(),u("div",null,[a(o(c),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(b),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{g as default};
//# sourceMappingURL=OidcLoginCallback.a89857fe.js.map
