import{O as a}from"./OmniChat.d015bfa8.js";import{u as s}from"./omniChatStore.3431c026.js";import{d as c,eb as i,u as t,o as d,a as l,h as u}from"./jwt-decode.esm.7f2ef0df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="b3441ae5-a3ce-4818-aecf-9deab7504afd",e._sentryDebugIdIdentifier="sentry-dbid-b3441ae5-a3ce-4818-aecf-9deab7504afd")}catch{}})();const b=c({__name:"ConsoleOmniChat",setup(e){const n=i().params.projectId,o=s();return o.init("console",n),(f,p)=>t(o).controller&&t(o).repository?(d(),l(a,{key:0,"ai-chat-repository":t(o).repository,controller:t(o).controller,environment:{origin:"console",projectId:t(n)}},null,8,["ai-chat-repository","controller","environment"])):u("",!0)}});export{b as _};
//# sourceMappingURL=ConsoleOmniChat.vue_vue_type_script_setup_true_lang.506f28c6.js.map
