import{_ as f}from"./Login.vue_vue_type_script_setup_true_lang.c2eb444c.js";import{d as l,e5 as m,eb as b,a5 as g,f as y,u as n,o as w,_ as k}from"./jwt-decode.esm.7f2ef0df.js";import{u as h}from"./workspaceStore.50ef2df1.js";import"./CircularLoading.fc66331b.js";import"./Logo.2de02c4a.js";import"./string.2ed1cde3.js";import"./index.51dbb698.js";import"./userStore.73b89fbb.js";import"./url.8583a595.js";import"./colorHelpers.71d6d61d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="77203dba-fafb-4611-94fd-d7206d953146",e._sentryDebugIdIdentifier="sentry-dbid-77203dba-fafb-4611-94fd-d7206d953146")}catch{}})();const v={class:"runner"},I=l({__name:"Login",setup(e){const o=m(),t=b(),r=h(),_=async()=>{const{redirect:a,...s}=t.query;if(a){await o.push({path:a,query:s,params:t.params});return}o.push({name:"playerHome",query:s})};return(a,s)=>{var d,c,p,u,i;return w(),g("div",v,[y(f,{"logo-url":(c=(d=n(r).state.workspace)==null?void 0:d.logoUrl)!=null?c:void 0,"brand-name":(p=n(r).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(r).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-12c690e1"]]);export{H as default};
//# sourceMappingURL=Login.409f4a11.js.map
