import{P as f}from"./PlayerNavbar.0fa6f760.js";import{d as g,e5 as h,eb as c,r as y,c as b,i as k,a5 as v,u as a,a as w,h as L,e as C,f as I,o as i,_ as N}from"./jwt-decode.esm.7f2ef0df.js";import{u as V}from"./workspaceStore.50ef2df1.js";import"./userStore.73b89fbb.js";import"./metadata.39f9b9ba.js";import"./PhUserList.vue.bce47902.js";import"./PhWebhooksLogo.vue.a704632d.js";import"./LoadingOutlined.cd84d9c9.js";import"./PhSignOut.vue.c9150da4.js";import"./index.03d222dd.js";import"./url.8583a595.js";import"./colorHelpers.71d6d61d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="20ce644c-461f-4c02-ae3d-84dbb4588e98",o._sentryDebugIdIdentifier="sentry-dbid-20ce644c-461f-4c02-ae3d-84dbb4588e98")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),d=c().path,n=y(null),u=async({path:r,id:s})=>{n.value=s,await e.push({path:`/${r}`}),n.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=b(()=>!!c().meta.hideLogin);return(r,s)=>{const m=k("RouterView");return i(),v("div",x,[a(t).state.workspace?(i(),w(f,{key:0,"current-path":a(d),"hide-login":_.value,"runner-data":a(t).state.workspace,loading:n.value,onNavigate:u,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(m)])])}}});const G=N(D,[["__scopeId","data-v-f095bece"]]);export{G as default};
//# sourceMappingURL=Main.4370ed68.js.map
