import{L as n}from"./Logo.2de02c4a.js";import{d as r,o as a,a as d,u as i}from"./jwt-decode.esm.7f2ef0df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="88e09c32-213b-4d85-9336-3387279574f9",e._sentryDebugIdIdentifier="sentry-dbid-88e09c32-213b-4d85-9336-3387279574f9")}catch{}})();const f="/assets/logo.0faadfa2.svg",p=r({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(s,t)=>{var o;return a(),d(n,{"image-url":i(f),"brand-name":"Abstra","hide-text":s.hideText,size:(o=s.size)!=null?o:"small"},null,8,["image-url","hide-text","size"])}}});export{p as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.3f03a3ef.js.map
