import{O as d}from"./workspaceStore.50ef2df1.js";import{d as l,J as i,a5 as u,f as a,b as o,u as n,o as c,g as r,A as f,da as b}from"./jwt-decode.esm.7f2ef0df.js";import"./userStore.73b89fbb.js";import"./url.8583a595.js";import"./colorHelpers.71d6d61d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b8c7b7c6-28aa-4631-86d5-5532f9fbb0a5",e._sentryDebugIdIdentifier="sentry-dbid-b8c7b7c6-28aa-4631-86d5-5532f9fbb0a5")}catch{}})();const g=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new d().logoutCallback()}),(t,s)=>(c(),u("div",null,[a(n(f),null,{default:o(()=>[r("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[r(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{g as default};
//# sourceMappingURL=OidcLogoutCallback.d151c695.js.map
