import{d as b,e5 as m,eb as p,o as l,a as f,b as c,a5 as _,ec as g,f as y,e as v,ed as k,u as n,aR as w}from"./jwt-decode.esm.7f2ef0df.js";import{A as I,T}from"./Card.1d1a9fb7.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="ec118428-2e33-4c65-b5ce-973895e613b1",e._sentryDebugIdIdentifier="sentry-dbid-ec118428-2e33-4c65-b5ce-973895e613b1")}catch{}})();const R=b({__name:"TablesTabs",setup(e){const a=m(),t=p(),u=String(t.name),d=t.params.projectId,r=[{label:"Tables list",value:"tables"},{label:"Diagram view",value:"tables-diagram"},{label:"Run SQL",value:"sql"}],i=o=>{a.push({name:String(o),params:{projectId:d}})};return(o,D)=>(l(),f(n(T),{"active-key":n(u),options:r,"onUpdate:activeKey":i},{default:c(()=>[(l(),_(w,null,g(r,s=>y(n(I),{key:s.value,name:s.value},{tab:c(()=>[v("span",null,k(s.label),1)]),_:2},1032,["name"])),64))]),_:1},8,["active-key"]))}});export{R as _};
//# sourceMappingURL=TablesTabs.vue_vue_type_script_setup_true_lang.63aa07d0.js.map
