import{C as t,E as i,K as d,a as f,M as c,c as b,P as l,R as y,S as g,b as u,T as k,U as p,e as w,l as D}from"./toggleHighContrast.c4e1b24d.js";import"./jwt-decode.esm.7f2ef0df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="fe1f8245-5cb7-444d-9e0b-e0f143ec0571",e._sentryDebugIdIdentifier="sentry-dbid-fe1f8245-5cb7-444d-9e0b-e0f143ec0571")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,f as KeyMod,c as MarkerSeverity,b as MarkerTag,l as Position,y as Range,g as Selection,u as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.65812c73.js.map
