import{d as o,o as s,a5 as a,f as d,u as _,S as c,_ as r}from"./jwt-decode.esm.7f2ef0df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="40f6f7c0-e148-4f48-bc3b-b029ec4f6bd5",e._sentryDebugIdIdentifier="sentry-dbid-40f6f7c0-e148-4f48-bc3b-b029ec4f6bd5")}catch{}})();const f={class:"centered"},i=o({__name:"LoadingContainer",setup(e){return(n,t)=>(s(),a("div",f,[d(_(c))]))}});const p=r(i,[["__scopeId","data-v-52e6209a"]]);export{p as L};
//# sourceMappingURL=LoadingContainer.6e2b63e4.js.map
