import{f as d,e7 as o,eX as u}from"./jwt-decode.esm.7f2ef0df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="774a3e78-f587-4a9d-88f1-477fe87e22fd",e._sentryDebugIdIdentifier="sentry-dbid-774a3e78-f587-4a9d-88f1-477fe87e22fd")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){l(e,a,n[a])})}return e}function l(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var f=function(t,n){var r=i({},t,n.attrs);return d(o,i({},r,{icon:u}),null)};f.displayName="LoadingOutlined";f.inheritAttrs=!1;const s=f;export{s as L};
//# sourceMappingURL=LoadingOutlined.cd84d9c9.js.map
