import"./jwt-decode.esm.7f2ef0df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="9ceac509-c87a-49dd-8878-dafb3881af6e",e._sentryDebugIdIdentifier="sentry-dbid-9ceac509-c87a-49dd-8878-dafb3881af6e")}catch{}})();const a=(...e)=>window.fetch(...e);export{a as l};
//# sourceMappingURL=fetch.5136a62d.js.map
