import{i as h}from"./metadata.39f9b9ba.js";import{W as k}from"./Watermark.891eee9f.js";import{F as b}from"./PhArrowSquareOut.vue.d0c95a06.js";import{d as v,e5 as w,c as x,r as C,u as e,a5 as m,f as p,b as r,h as D,o as t,a as n,g as f,T as y,aR as I,ec as z,de as _,ef as T,ed as F,ea as B,_ as H}from"./jwt-decode.esm.7f2ef0df.js";import{u as L}from"./workspaceStore.50ef2df1.js";import"./index.4b93c8ad.js";import{L as N}from"./LoadingOutlined.cd84d9c9.js";import{C as S}from"./Card.1d1a9fb7.js";import"./PhUserList.vue.bce47902.js";import"./PhWebhooksLogo.vue.a704632d.js";import"./constants.56e8988f.js";import"./userStore.73b89fbb.js";import"./url.8583a595.js";import"./colorHelpers.71d6d61d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},i=new Error().stack;i&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[i]="dcfeb4e0-5480-47ab-ab05-8a6603cd7294",o._sentryDebugIdIdentifier="sentry-dbid-dcfeb4e0-5480-47ab-ab05-8a6603cd7294")}catch{}})();const V={key:0,class:"home-container"},W=v({__name:"Home",setup(o){const i=w(),l=L(),u=x(()=>{var s;return((s=l.state.workspace)==null?void 0:s.sidebar.filter(d=>d.id!=="home"))||[]}),c=C(null),g=async(s,d)=>{c.value=d,await i.push({path:`/${s}`}),c.value=null};return(s,d)=>e(l).state.workspace?(t(),m("div",V,[p(e(_),{vertical:"",gap:"large",class:"cards-container"},{default:r(()=>[u.value.length===0?(t(),n(e(y),{key:0,type:"secondary",style:{"font-size":"18px"}},{default:r(()=>[f(" There are no forms available for you. ")]),_:1})):(t(!0),m(I,{key:1},z(u.value,a=>(t(),n(e(S),{key:a.id,class:B(["form-card",{loading:c.value===a.id}]),"body-style":{cursor:"pointer"},onClick:E=>g(a.path,a.id)},{default:r(()=>[p(e(_),{gap:"large",align:"center",justify:"space-between"},{default:r(()=>[(t(),n(T(e(h)(a.type)),{style:{"flex-shrink":"0",width:"22px",height:"18px"}})),p(e(y),{style:{"font-size":"18px","font-weight":"500"}},{default:r(()=>[f(F(a.name),1)]),_:2},1024),c.value!==a.id?(t(),n(e(b),{key:0,size:"20"})):(t(),n(e(N),{key:1,style:{"font-size":"20px"}}))]),_:2},1024)]),_:2},1032,["class","onClick"]))),128))]),_:1}),p(k,{class:"watermark","page-id":"home",locale:e(l).state.workspace.language},null,8,["locale"])])):D("",!0)}});const Y=H(W,[["__scopeId","data-v-060376d1"]]);export{Y as default};
//# sourceMappingURL=Home.80c7e349.js.map
