import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.ee5d447b.js";import{d as i,eb as s,a as m,u as c,o as d}from"./jwt-decode.esm.7f2ef0df.js";import"./router.8fd5b2ad.js";import"./index.9021ba5d.js";import"./fetch.5136a62d.js";import"./record.4ffc477c.js";import"./SaveButton.fdf70b31.js";import"./ExclamationCircleOutlined.6d10f60b.js";import"./CrudView.c16e2f81.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.61381525.js";import"./constants.56e8988f.js";import"./url.8583a595.js";import"./PhDotsThreeVertical.vue.0ea03d82.js";import"./index.23283fbb.js";import"./asyncComputed.25309626.js";import"./omniChatStore.3431c026.js";import"./uuid.dadede91.js";import"./PhCopySimple.vue.43c74ebe.js";import"./PhPencil.vue.80ed4b2e.js";import"./useCodebaseEvents.42573b00.js";import"./contracts.generated.c4057ed0.js";import"./index.51dbb698.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="f36e1c1d-3277-48d8-9584-6de884c2cf1c",o._sentryDebugIdIdentifier="sentry-dbid-f36e1c1d-3277-48d8-9584-6de884c2cf1c")}catch{}})();const A=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(a,f)=>(d(),m(n,{"env-var-repository":c(t),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.242b97c2.js.map
