import"./jwt-decode.esm.7f2ef0df.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[s]="959f8775-fa74-4c2d-ab4c-5889b7cb7c10",t._sentryDebugIdIdentifier="sentry-dbid-959f8775-fa74-4c2d-ab4c-5889b7cb7c10")}catch{}})();const e={HOMEPAGE:{}.VITE_HOMEPAGE_URL||"https://abstra.io",DOCS:{}.VITE_DOCS_URL||"https://abstra.io/docs",CLOUD:{}.VITE_CONSOLE_URL||"https://cloud.abstra.io",GITHUB:{}.VITE_GITHUB_URL||"https://github.com/abstra-app/abstra-lib"},b=t=>{if(!t)return e.DOCS;const s=t.startsWith("/")?t.slice(1):t;return`${e.DOCS}/${s}`};export{e as A,b};
//# sourceMappingURL=constants.56e8988f.js.map
