import{d as o,o as d,a5 as s,e as l,a7 as r,ea as t,_ as f}from"./jwt-decode.esm.7f2ef0df.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[e]="601aac89-28c8-47b6-bfa8-4b65a61f016a",a._sentryDebugIdIdentifier="sentry-dbid-601aac89-28c8-47b6-bfa8-4b65a61f016a")}catch{}})();const c=o({__name:"ContentLayout",props:{fullWidth:{type:Boolean},noPadding:{type:Boolean}},setup(a){return(e,n)=>(d(),s("div",{class:t(["content-layout",{"no-padding":e.noPadding}])},[l("div",{class:t(["centered-layout",{"full-width":e.fullWidth}])},[r(e.$slots,"default",{},void 0,!0)],2)],2))}});const u=f(c,[["__scopeId","data-v-fb4d67f9"]]);export{u as C};
//# sourceMappingURL=ContentLayout.228d2328.js.map
