import{X as d,dJ as a,dK as i}from"./jwt-decode.esm.7f2ef0df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="5e130b86-087d-45e2-80bf-bfb287dcc41c",e._sentryDebugIdIdentifier="sentry-dbid-5e130b86-087d-45e2-80bf-bfb287dcc41c")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:b,QuarterPicker:c,RangePicker:o}=a(i),u=d(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:b,QuarterPicker:c,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(c.name,c),e)});export{u as D,r as M,c as Q,o as R,t as W};
//# sourceMappingURL=dayjs.c54f8edb.js.map
