import{h as n}from"./router.8fd5b2ad.js";import"./jwt-decode.esm.7f2ef0df.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="724234d9-f242-4a19-b2bd-61d0f2155eea",r._sentryDebugIdIdentifier="sentry-dbid-724234d9-f242-4a19-b2bd-61d0f2155eea")}catch{}})();class s{async create(e){return n.post(`organizations/${e.organizationId}/members`,{email:e.email,folderIds:e.folderIds})}async delete(e){return n.delete(`organizations/${e.organizationId}/members/${e.authorId}`)}async list(e){return n.get(`organizations/${e}/members`)}async get(e,t){return n.get(`organizations/${e}/members/${t}`)}async update(e,t,a){return n.patch(`organizations/${e}/members/${t}`,a)}}export{s as M};
//# sourceMappingURL=member.b7ac8000.js.map
