import{f as c,e7 as d,eY as o}from"./jwt-decode.esm.7f2ef0df.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="7dcbd0c5-42ac-49d1-a020-f6637db52af8",e._sentryDebugIdIdentifier="sentry-dbid-7dcbd0c5-42ac-49d1-a020-f6637db52af8")}catch{}})();function a(e){for(var t=1;t<arguments.length;t++){var r=arguments[t]!=null?Object(arguments[t]):{},n=Object.keys(r);typeof Object.getOwnPropertySymbols=="function"&&(n=n.concat(Object.getOwnPropertySymbols(r).filter(function(i){return Object.getOwnPropertyDescriptor(r,i).enumerable}))),n.forEach(function(i){f(e,i,r[i])})}return e}function f(e,t,r){return t in e?Object.defineProperty(e,t,{value:r,enumerable:!0,configurable:!0,writable:!0}):e[t]=r,e}var l=function(t,r){var n=a({},t,r.attrs);return c(d,a({},n,{icon:o}),null)};l.displayName="CloseCircleOutlined";l.inheritAttrs=!1;const s=l;export{s as C};
//# sourceMappingURL=CloseCircleOutlined.0110bbe2.js.map
